@@ -70,12 +70,13 @@ func serve(cfg AssetConfig, response http.ResponseWriter, request *http.Request)
 		assetPath = cfg.IndexPath
 	}
 
-	if fin, err := fetchAsset(cfg, assetPath); err != nil {
+	if assetFile, err := fetchAsset(cfg, assetPath); err != nil {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusNotFound, api.ErrorResponseDetailsResourceNotFound, request), response)
-	} else if fileInfo, err := fin.Stat(); err != nil || fileInfo == nil {
+	} else if fileInfo, err := assetFile.Stat(); err != nil || fileInfo == nil {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusInternalServerError, api.ErrorResponseDetailsInternalServerError, request), response)
+		assetFile.Close()
 	} else {
-		defer fin.Close()
+		defer assetFile.Close()
 
 		var (
 			assetExtension = filepath.Ext(fileInfo.Name())
@@ -90,7 +91,7 @@ func serve(cfg AssetConfig, response http.ResponseWriter, request *http.Request)
 		response.Header().Set(headers.ContentType.String(), contentType)
 		response.Header().Set(headers.StrictTransportSecurity.String(), utils.HSTSSetting)
 
-		if _, err := io.Copy(response, fin); err != nil {
+		if _, err := io.Copy(response, assetFile); err != nil {
 			slog.ErrorContext(request.Context(), fmt.Sprintf("Failed flushing static file content for asset %s to client: %v", assetPath, err))
 		}
 	}
