@@ -44,7 +44,7 @@ func (s Resources) RequestAnalysis(response http.ResponseWriter, request *http.R
 
 	var userId string
 	if user, isUser := auth.GetUserFromAuthCtx(ctx.FromRequest(request).AuthCtx); !isUser {
-		slog.WarnContext(request.Context(), "encountered request analysis for unknown user, this shouldn't happen")
+		slog.WarnContext(request.Context(), "Encountered request analysis for unknown user, this shouldn't happen")
 		userId = "unknown-user"
 	} else {
 		userId = user.ID.String()
