@@ -17,8 +17,8 @@
 package v2
 
 import (
+	"context"
 	"encoding/json"
-
 	"errors"
 	"net/http"
 	"slices"
@@ -26,6 +26,7 @@ import (
 
 	"github.com/gofrs/uuid"
 	"github.com/gorilla/mux"
+
 	"github.com/specterops/bloodhound/cmd/api/src/api"
 	"github.com/specterops/bloodhound/cmd/api/src/auth"
 	ctx2 "github.com/specterops/bloodhound/cmd/api/src/ctx"
@@ -78,6 +79,66 @@ func CanUpdateSavedQueriesPermission(user model.User, savedQueryBelongsToUser bo
 	return ErrForbidden
 }
 
+type SavedQueryPermissionResponse struct {
+	QueryID         int64       `json:"query_id"`
+	Public          bool        `json:"public"`
+	SharedToUserIDs []uuid.UUID `json:"shared_to_user_ids"`
+}
+
+func (s *SavedQueryPermissionResponse) appendUserId(userId uuid.NullUUID) {
+	if s.SharedToUserIDs == nil {
+		s.SharedToUserIDs = make([]uuid.UUID, 0)
+	}
+	if userId.Valid {
+		s.SharedToUserIDs = append(s.SharedToUserIDs, userId.UUID)
+	}
+}
+
+// GetSavedQueryPermissions - returns the query permissions for users who own the query or admins.
+// Public queries will return for any user with no attached user ids.
+// QueryPermissions indicate if the query is public or private, and if private, who the query is shared with.
+func (s Resources) GetSavedQueryPermissions(response http.ResponseWriter, request *http.Request) {
+	var rawSavedQueryID = mux.Vars(request)[api.URIPathVariableSavedQueryID]
+
+	if user, isUser := auth.GetUserFromAuthCtx(ctx2.FromRequest(request).AuthCtx); !isUser {
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, "no associated user found", request), response)
+	} else if savedQueryID, err := strconv.ParseInt(rawSavedQueryID, 10, 64); err != nil {
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusBadRequest, api.ErrorResponseDetailsIDMalformed, request), response)
+	} else if savedQueryPermissions, err := s.DB.GetSavedQueryPermissions(request.Context(), savedQueryID); err != nil {
+		api.HandleDatabaseError(request, response, err)
+	} else if len(savedQueryPermissions) == 0 {
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusNotFound, "no query permissions exist for saved query", request), response)
+	} else if isAccessibleToUser, err := s.canUserAccessSavedQueryPermissions(request.Context(), savedQueryPermissions[0], user); err != nil {
+		api.HandleDatabaseError(request, response, err)
+	} else if !isAccessibleToUser {
+		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusNotFound, "no query permissions exist for saved query", request), response)
+	} else {
+		var savedQueryPermissionResponse = SavedQueryPermissionResponse{
+			QueryID:         savedQueryID,
+			Public:          savedQueryPermissions[0].Public,
+			SharedToUserIDs: make([]uuid.UUID, 0),
+		}
+		if !savedQueryPermissionResponse.Public {
+			for _, savedQueryPermission := range savedQueryPermissions {
+				savedQueryPermissionResponse.appendUserId(savedQueryPermission.SharedToUserID)
+			}
+		}
+		api.WriteBasicResponse(request.Context(), savedQueryPermissionResponse, http.StatusOK, response)
+	}
+}
+
+// canUserAccessSavedQueryPermissions - users can access query permissions if its public, they own the query or are an admin.
+func (s Resources) canUserAccessSavedQueryPermissions(ctx context.Context, savedQueryPermissions model.SavedQueriesPermissions, user model.User) (bool, error) {
+	if savedQueryPermissions.Public || user.Roles.Has(model.Role{Name: auth.RoleAdministrator}) {
+		return true, nil
+	}
+	if savedQuery, err := s.DB.GetSavedQuery(ctx, savedQueryPermissions.QueryID); err != nil {
+		return false, err
+	} else {
+		return user.ID.String() == savedQuery.UserID, nil
+	}
+}
+
 // ShareSavedQueries allows a user to share queries between users, as well as share them publicly
 func (s Resources) ShareSavedQueries(response http.ResponseWriter, request *http.Request) {
 	var (
