@@ -33,6 +33,7 @@ type PermissionSet struct {
 	AuthManageProviders                 model.Permission
 	AuthManageSelf                      model.Permission
 	AuthManageUsers                     model.Permission
+	AuthReadUsers                       model.Permission
 
 	ClientsManage  model.Permission
 	ClientsRead    model.Permission
@@ -72,6 +73,7 @@ func (s PermissionSet) All() model.Permissions {
 		s.GraphDBWrite,
 		s.SavedQueriesRead,
 		s.SavedQueriesWrite,
+		s.AuthReadUsers,
 		s.WipeDB,
 	}
 }
@@ -91,6 +93,7 @@ func Permissions() PermissionSet {
 		AuthManageProviders:                 model.NewPermission("auth", "ManageProviders"),
 		AuthManageSelf:                      model.NewPermission("auth", "ManageSelf"),
 		AuthManageUsers:                     model.NewPermission("auth", "ManageUsers"),
+		AuthReadUsers:                       model.NewPermission("auth", "ReadUsers"),
 
 		ClientsManage:  model.NewPermission("clients", "Manage"),
 		ClientsRead:    model.NewPermission("clients", "Read"),
