@@ -40,6 +40,7 @@ const (
 type AssetGroupTagData interface {
 	CreateAssetGroupTag(ctx context.Context, tagType model.AssetGroupTagType, user model.User, name string, description string, position null.Int32, requireCertify null.Bool, glyph null.String) (model.AssetGroupTag, error)
 	UpdateAssetGroupTag(ctx context.Context, user model.User, tag model.AssetGroupTag) (model.AssetGroupTag, error)
+	SanitizeUpdateAssetGroupTagRequireCertify(tag *model.AssetGroupTag)
 	DeleteAssetGroupTag(ctx context.Context, user model.User, assetGroupTag model.AssetGroupTag) error
 	GetAssetGroupTag(ctx context.Context, assetGroupTagId int) (model.AssetGroupTag, error)
 	GetAssetGroupTags(ctx context.Context, sqlFilter model.SQLFilter) (model.AssetGroupTags, error)
@@ -49,7 +50,7 @@ type AssetGroupTagData interface {
 
 // AssetGroupTagSelectorData defines the methods required to interact with the asset_group_tag_selectors and asset_group_tag_selector_seeds tables
 type AssetGroupTagSelectorData interface {
-	CreateAssetGroupTagSelector(ctx context.Context, assetGroupTagId int, user model.User, name string, description string, isDefault bool, allowDisable bool, autoCertify null.Bool, seeds []model.SelectorSeed) (model.AssetGroupTagSelector, error)
+	CreateAssetGroupTagSelector(ctx context.Context, assetGroupTagId int, user model.User, name string, description string, isDefault bool, allowDisable bool, autoCertify model.SelectorAutoCertifyMethod, seeds []model.SelectorSeed) (model.AssetGroupTagSelector, error)
 	GetAssetGroupTagSelectorBySelectorId(ctx context.Context, assetGroupTagSelectorId int) (model.AssetGroupTagSelector, error)
 	UpdateAssetGroupTagSelector(ctx context.Context, actorId, email string, selector model.AssetGroupTagSelector) (model.AssetGroupTagSelector, error)
 	DeleteAssetGroupTagSelector(ctx context.Context, user model.User, selector model.AssetGroupTagSelector) error
@@ -83,7 +84,7 @@ func insertSelectorSeeds(tx *gorm.DB, selectorId int, seeds []model.SelectorSeed
 	return seeds, nil
 }
 
-func (s *BloodhoundDB) CreateAssetGroupTagSelector(ctx context.Context, assetGroupTagId int, user model.User, name string, description string, isDefault bool, allowDisable bool, autoCertify null.Bool, seeds []model.SelectorSeed) (model.AssetGroupTagSelector, error) {
+func (s *BloodhoundDB) CreateAssetGroupTagSelector(ctx context.Context, assetGroupTagId int, user model.User, name string, description string, isDefault bool, allowDisable bool, autoCertify model.SelectorAutoCertifyMethod, seeds []model.SelectorSeed) (model.AssetGroupTagSelector, error) {
 	var (
 		userIdStr = user.ID.String()
 		selector  = model.AssetGroupTagSelector{
@@ -103,10 +104,6 @@ func (s *BloodhoundDB) CreateAssetGroupTagSelector(ctx context.Context, assetGro
 		}
 	)
 
-	if !autoCertify.Valid {
-		return model.AssetGroupTagSelector{}, fmt.Errorf("auto_certify must be set to true or false")
-	}
-
 	if err := s.AuditableTransaction(ctx, auditEntry, func(tx *gorm.DB) error {
 		bhdb := NewBloodhoundDB(tx, s.idResolver)
 		if result := tx.Raw(fmt.Sprintf(`
@@ -379,6 +376,11 @@ func (s *BloodhoundDB) CreateAssetGroupTag(ctx context.Context, tagType model.As
 	return tag, nil
 }
 
+func (s *BloodhoundDB) SanitizeUpdateAssetGroupTagRequireCertify(tag *model.AssetGroupTag) {
+	// Forces all BHCE tags to not require certification
+	tag.RequireCertify = null.BoolFrom(false)
+}
+
 func (s *BloodhoundDB) UpdateAssetGroupTag(ctx context.Context, user model.User, tag model.AssetGroupTag) (model.AssetGroupTag, error) {
 	var (
 		auditEntry = model.AuditEntry{
@@ -851,9 +853,10 @@ func (s *BloodhoundDB) GetAggregatedSelectorNodesCertification(ctx context.Conte
 	// with the lowest position zone, then finding the row with highest value of certified and grabbing the earliest created_at date seen across rows.
 	baseQuery := fmt.Sprintf(`
 		WITH nodes_associated_with_min_pos AS (
-			SELECT 
-				n.*, 
+			SELECT
+				n.*,
 				t.position,
+				t.require_certify,
 				s.asset_group_tag_id,
 				MIN(t.position) OVER (PARTITION BY n.node_id) AS min_position_for_node
 			FROM %s n
@@ -877,7 +880,7 @@ func (s *BloodhoundDB) GetAggregatedSelectorNodesCertification(ctx context.Conte
 				MIN(sort.created_at) OVER (PARTITION BY sort.node_id) AS created_at,    -- make a column that tracks the earliest created_at for a given node_id
 				sort.asset_group_tag_id
 			FROM nodes_associated_with_min_pos sort
-			WHERE sort.position = sort.min_position_for_node
+			WHERE sort.position = sort.min_position_for_node AND sort.require_certify = true
 			ORDER BY sort.node_id, sort.certified DESC     -- when there are multiple rows of same node_id, take the one with the highest value of certified
 		)`,
 		model.AssetGroupSelectorNode{}.TableName(),
@@ -890,7 +893,7 @@ func (s *BloodhoundDB) GetAggregatedSelectorNodesCertification(ctx context.Conte
 			hybrid.node_id,
 			hybrid.selector_id,
 			hybrid.certified,
-			hybrid.certified_by,  
+			hybrid.certified_by,
 			hybrid.source,
 			hybrid.node_primary_kind,
 			hybrid.node_environment_id,
@@ -901,7 +904,7 @@ func (s *BloodhoundDB) GetAggregatedSelectorNodesCertification(ctx context.Conte
 			hybrid.created_at,
 			hybrid.asset_group_tag_id
 		FROM sort_on_created_at hybrid
-		%s 
+		%s
 		ORDER BY hybrid.node_id ASC
 		%s;`,
 		sqlFilter.SQLString,
@@ -912,7 +915,7 @@ func (s *BloodhoundDB) GetAggregatedSelectorNodesCertification(ctx context.Conte
 	} else {
 		// get a total count on the above query without pagination
 		countQuery := fmt.Sprintf(`
-			SELECT COUNT(*) 
+			SELECT COUNT(*)
 			FROM sort_on_created_at %s;`,
 			sqlFilter.SQLString)
 
@@ -1001,11 +1004,11 @@ func (s *BloodhoundDB) GetAssetGroupSelectorNodeExpandedOrderedByIdAndPosition(c
 				FROM %s n
 				JOIN %s s ON n.selector_id = s.id
 				JOIN %s t ON s.asset_group_tag_id = t.id
-				WHERE n.node_id IN ? AND t.type = ? AND n.certified != ?
+				WHERE n.node_id IN ? AND t.type = ?
 				ORDER BY n.node_id DESC, position ASC`,
 		model.AssetGroupSelectorNode{}.TableName(),
 		model.AssetGroupTagSelector{}.TableName(),
 		model.AssetGroupTag{}.TableName()),
-		nodeIds, model.AssetGroupTagTypeTier, model.AssetGroupCertificationAuto).
+		nodeIds, model.AssetGroupTagTypeTier).
 		Find(&nodes))
 }
