@@ -298,6 +298,14 @@ func (s *BloodhoundDB) UpdateUser(ctx context.Context, user model.User) error {
 			return err
 		}
 
+		// Clear a user's etac list before applying their new one when saving the user model
+		if user.AllEnvironments || user.EnvironmentTargetedAccessControl != nil {
+			bhdb := NewBloodhoundDB(tx, s.idResolver)
+			if err := bhdb.DeleteEnvironmentTargetedAccessControlForUser(ctx, user); err != nil {
+				return fmt.Errorf("error deleting user's environment list: %w", err)
+			}
+		}
+
 		// AuthSecret must be manually retrieved and deleted
 		if user.AuthSecret == nil {
 			var authSecret model.AuthSecret
