@@ -56,7 +56,7 @@ func (BarTest) TableName() string {
 // TestMigrator_LatestMigration tests that the Migrator can retrieve
 // the last migration entry in the `migration` table.
 func TestMigrator_LatestMigration(t *testing.T) {
-	_, migrator, err := integration.SetupTestMigrator(migration.Source{FileSystem: testMigrationSystem1, Directory: "test_migrations/system1"})
+	_, migrator, err := integration.SetupTestMigrator(t, migration.Source{FileSystem: testMigrationSystem1, Directory: "test_migrations/system1"})
 	require.Nil(t, err)
 
 	require.Nil(t, migrator.CreateMigrationSchema())
@@ -88,7 +88,7 @@ func TestMigrator_ExecuteMigrations(t *testing.T) {
 		fooTests    []FooTest
 		barTests    []BarTest
 	)
-	db, migrator, err := integration.SetupTestMigrator(
+	db, migrator, err := integration.SetupTestMigrator(t,
 		migration.Source{FileSystem: testMigrationSystem1, Directory: "test_migrations/system1"},
 		migration.Source{FileSystem: testMigrationSystem2, Directory: "test_migrations/system2"},
 	)
@@ -221,7 +221,7 @@ func TestMigrator_ExecuteMigrations(t *testing.T) {
 // TestMigrator_HasMigrationTable makes sure the Migrator can properly
 // detect the `migrations` table.
 func TestMigrator_HasMigrationTable(t *testing.T) {
-	_, migrator, err := integration.SetupTestMigrator()
+	_, migrator, err := integration.SetupTestMigrator(t)
 	require.Nil(t, err)
 
 	require.Nil(t, migrator.CreateMigrationSchema())
@@ -253,7 +253,7 @@ func TestMigrator_CreateMigrationSchema(t *testing.T) {
 		count       int64
 	)
 
-	db, migrator, err := integration.SetupTestMigrator()
+	db, migrator, err := integration.SetupTestMigrator(t)
 	require.Nil(t, err)
 
 	assert.Nil(t, migrator.CreateMigrationSchema())
@@ -280,7 +280,7 @@ func TestMigrator_CreateMigrationSchema(t *testing.T) {
 
 // TestMigrator_Migrate tests the integrity of FossMigrations.
 func TestMigrator_Migrate(t *testing.T) {
-	_, migrator, err := integration.SetupTestMigrator(migration.Source{FileSystem: migration.FossMigrations, Directory: "migrations"})
+	_, migrator, err := integration.SetupTestMigrator(t, migration.Source{FileSystem: migration.FossMigrations, Directory: "migrations"})
 	require.Nil(t, err)
 
 	manifest, err := migrator.GenerateManifest()
