@@ -18,6 +18,8 @@ package database
 
 import (
 	"context"
+	"fmt"
+	"strings"
 
 	"github.com/gofrs/uuid"
 	"gorm.io/gorm"
@@ -27,7 +29,7 @@ import (
 
 type SavedQueriesData interface {
 	GetSavedQuery(ctx context.Context, savedQueryID int64) (model.SavedQuery, error)
-	ListSavedQueries(ctx context.Context, userID uuid.UUID, order string, filter model.SQLFilter, skip, limit int) (model.SavedQueries, int, error)
+	ListSavedQueries(ctx context.Context, scope string, userID uuid.UUID, order string, filter model.SQLFilter, skip, limit int) ([]model.ScopedSavedQuery, int, error)
 	CreateSavedQuery(ctx context.Context, userID uuid.UUID, name string, query string, description string) (model.SavedQuery, error)
 	UpdateSavedQuery(ctx context.Context, savedQuery model.SavedQuery) (model.SavedQuery, error)
 	DeleteSavedQuery(ctx context.Context, savedQueryID int64) error
@@ -36,6 +38,7 @@ type SavedQueriesData interface {
 	GetPublicSavedQueries(ctx context.Context) (model.SavedQueries, error)
 	CreateSavedQueries(ctx context.Context, savedQueries model.SavedQueries) error
 	GetAllSavedQueriesByUser(ctx context.Context, userID uuid.UUID) (model.SavedQueries, error)
+	GetSavedQueriesOwnedBy(ctx context.Context, userID uuid.UUID) (model.SavedQueries, error)
 }
 
 func (s *BloodhoundDB) GetSavedQuery(ctx context.Context, savedQueryID int64) (model.SavedQuery, error) {
@@ -44,31 +47,53 @@ func (s *BloodhoundDB) GetSavedQuery(ctx context.Context, savedQueryID int64) (m
 	return savedQuery, CheckError(result)
 }
 
-func (s *BloodhoundDB) ListSavedQueries(ctx context.Context, userID uuid.UUID, order string, filter model.SQLFilter, skip, limit int) (model.SavedQueries, int, error) {
+func (s *BloodhoundDB) ListSavedQueries(ctx context.Context, scope string, userID uuid.UUID, order string, filter model.SQLFilter, skip, limit int) ([]model.ScopedSavedQuery, int, error) {
 	var (
-		queries model.SavedQueries
-		result  *gorm.DB
-		count   int64
-		cursor  = s.Scope(Paginate(skip, limit)).WithContext(ctx).Where("user_id = ?", userID)
+		queries []model.ScopedSavedQuery
+		// cant chain scope + cursor after declaration so must declare twice
+		countCursor    = s.db.WithContext(ctx).Select("DISTINCT sq.*, CASE WHEN (sqp.public = TRUE AND sq.user_id <> ?) THEN 'public' WHEN sqp.shared_to_user_id = ? THEN 'shared' ELSE 'owned' END AS scope", userID, userID).Table("saved_queries sq").Joins("LEFT JOIN public.saved_queries_permissions sqp ON sq.id = sqp.query_id")
+		cursor         = s.Scope(Paginate(skip, limit)).WithContext(ctx).Select("DISTINCT sq.*, CASE WHEN (sqp.public = TRUE AND sq.user_id <> ?) THEN 'public' WHEN sqp.shared_to_user_id = ? THEN 'shared' ELSE 'owned' END AS scope", userID, userID).Table("saved_queries sq").Joins("LEFT JOIN public.saved_queries_permissions sqp ON sq.id = sqp.query_id")
+		orderReplacer  = strings.NewReplacer("id", "sq.id", "created_at", "sq.created_at", "updated_at", "sq.updated_at")
+		filterReplacer = strings.NewReplacer("id", "sq.id")
+		count          int64
 	)
 
+	// replace ambiguous identifiers with the desired table prefix
+	order = orderReplacer.Replace(order)
+	filter.SQLString = filterReplacer.Replace(filter.SQLString)
+
+	switch strings.ToLower(scope) {
+	case string(model.SavedQueryScopeOwned):
+		cursor = cursor.Where("sq.user_id = ?", userID)
+		countCursor = countCursor.Where("sq.user_id = ?", userID)
+	case string(model.SavedQueryScopeShared):
+		cursor = cursor.Where("sqp.shared_to_user_id = ?", userID)
+		countCursor = countCursor.Where("sqp.shared_to_user_id = ?", userID)
+	case string(model.SavedQueryScopePublic):
+		cursor = cursor.Where("sqp.public = TRUE")
+		countCursor = countCursor.Where("sqp.public = TRUE")
+	case string(model.SavedQueryScopeAll):
+		cursor = cursor.Where("sqp.public = TRUE OR sq.user_id = ? OR sqp.shared_to_user_id = ?", userID, userID)
+		countCursor = countCursor.Where("sqp.public = TRUE OR sq.user_id = ? OR sqp.shared_to_user_id = ?", userID, userID)
+	default:
+		return nil, 0, fmt.Errorf("invalid scope parameter: %s", scope)
+	}
+
 	if filter.SQLString != "" {
 		cursor = cursor.Where(filter.SQLString, filter.Params...)
-		result = s.db.Model(&queries).WithContext(ctx).Where("user_id = ?", userID).Where(filter.SQLString, filter.Params...).Count(&count)
-	} else {
-		result = s.db.Model(&queries).WithContext(ctx).Where("user_id = ?", userID).Count(&count)
+		countCursor = countCursor.Where(filter.SQLString, filter.Params...)
 	}
-
-	if result.Error != nil {
-		return queries, 0, result.Error
-	}
-
 	if order != "" {
 		cursor = cursor.Order(order)
+		countCursor = countCursor.Order(order)
+	}
+
+	result := countCursor.Count(&count)
+	if result.Error != nil {
+		return nil, 0, CheckError(result)
 	}
 
 	result = cursor.Find(&queries)
-
 	return queries, int(count), CheckError(result)
 }
 
@@ -95,11 +120,8 @@ func (s *BloodhoundDB) SavedQueryBelongsToUser(ctx context.Context, userID uuid.
 	var savedQuery model.SavedQuery
 	if result := s.db.WithContext(ctx).First(&savedQuery, savedQueryID); result.Error != nil {
 		return false, CheckError(result)
-	} else if savedQuery.UserID == userID.String() {
-		return true, nil
-	} else {
-		return false, nil
 	}
+	return savedQuery.UserID == userID.String(), nil
 }
 
 // GetSharedSavedQueries returns all the saved queries that the given userID has access to, including global queries
@@ -127,6 +149,12 @@ func (s *BloodhoundDB) GetAllSavedQueriesByUser(ctx context.Context, userID uuid
 	return savedQueries, CheckError(results)
 }
 
+func (s *BloodhoundDB) GetSavedQueriesOwnedBy(ctx context.Context, userID uuid.UUID) (model.SavedQueries, error) {
+	savedQueries := model.SavedQueries{}
+	result := s.db.WithContext(ctx).Where("user_id = ?", userID).Find(&savedQueries)
+	return savedQueries, CheckError(result)
+}
+
 // CreateSavedQueries - inserts saved queries records in batches
 func (s *BloodhoundDB) CreateSavedQueries(ctx context.Context, savedQueries model.SavedQueries) error {
 	return s.db.Transaction(func(tx *gorm.DB) error {
