@@ -25,12 +25,14 @@ import (
 	"strconv"
 	"strings"
 
+	"github.com/specterops/dawgs/cypher/models"
 	"github.com/specterops/dawgs/cypher/models/pgsql"
 	"github.com/specterops/dawgs/cypher/models/pgsql/format"
 
-	"github.com/specterops/bloodhound/packages/go/graphschema/common"
 	"github.com/specterops/dawgs/graph"
 	"github.com/specterops/dawgs/query"
+
+	"github.com/specterops/bloodhound/packages/go/graphschema/common"
 )
 
 type FilterOperator string
@@ -195,10 +197,12 @@ func filterValueAsPGLiteral(valueStr string, isNullValue bool) (pgsql.Literal, e
 
 // BuildSQLFilter builds a PGSQL syntax-correct SQLFilter result from the given Filters struct. This function
 // uses the PGSQL AST to ensure formatted SQL correctness.
-func BuildSQLFilter(filters Filters) (SQLFilter, error) {
+func BuildSQLFilter(filters Filters, tableAlias models.Optional[string]) (SQLFilter, error) {
 	var whereClauseFragment pgsql.Expression
 
 	for name, filterOperations := range filters {
+		formattedName := strings.TrimSpace(strings.ToLower(name))
+
 		for _, filter := range filterOperations {
 			var (
 				operator    pgsql.Operator
@@ -244,8 +248,14 @@ func BuildSQLFilter(filters Filters) (SQLFilter, error) {
 			if literalValue, err := filterValueAsPGLiteral(filterValue, isNullValue); err != nil {
 				return SQLFilter{}, fmt.Errorf("invalid filter value specified for %s: %w", name, err)
 			} else {
+				var columnReference pgsql.Expression = pgsql.Identifier(formattedName)
+
+				if tableAlias.Set {
+					columnReference = pgsql.AsCompoundIdentifier(tableAlias.Value, formattedName)
+				}
+
 				whereClauseFragment = pgsql.OptionalAnd(whereClauseFragment, pgsql.NewBinaryExpression(
-					pgsql.Identifier(name),
+					columnReference,
 					operator,
 					literalValue,
 				))
@@ -268,8 +278,12 @@ func BuildSQLFilter(filters Filters) (SQLFilter, error) {
 	return filter, nil
 }
 
+func (s QueryParameterFilterMap) BuildAliasedSQLFilter(tableAlias models.Optional[string]) (SQLFilter, error) {
+	return BuildSQLFilter(s.ToFiltersModel(), tableAlias)
+}
+
 func (s QueryParameterFilterMap) BuildSQLFilter() (SQLFilter, error) {
-	return BuildSQLFilter(s.ToFiltersModel())
+	return s.BuildAliasedSQLFilter(models.EmptyOptional[string]())
 }
 
 func guessFilterValueType(raw string) any {
