@@ -22,6 +22,8 @@ import (
 	"log/slog"
 	"time"
 
+	"github.com/specterops/dawgs/graph"
+
 	"github.com/specterops/bloodhound/cmd/api/src/api"
 	"github.com/specterops/bloodhound/cmd/api/src/api/registration"
 	"github.com/specterops/bloodhound/cmd/api/src/api/router"
@@ -31,6 +33,7 @@ import (
 	"github.com/specterops/bloodhound/cmd/api/src/daemons"
 	"github.com/specterops/bloodhound/cmd/api/src/daemons/api/bhapi"
 	"github.com/specterops/bloodhound/cmd/api/src/daemons/api/toolapi"
+	"github.com/specterops/bloodhound/cmd/api/src/daemons/changelog"
 	"github.com/specterops/bloodhound/cmd/api/src/daemons/datapipe"
 	"github.com/specterops/bloodhound/cmd/api/src/daemons/gc"
 	"github.com/specterops/bloodhound/cmd/api/src/database"
@@ -39,7 +42,6 @@ import (
 	"github.com/specterops/bloodhound/cmd/api/src/services/upload"
 	"github.com/specterops/bloodhound/packages/go/cache"
 	schema "github.com/specterops/bloodhound/packages/go/graphschema"
-	"github.com/specterops/dawgs/graph"
 )
 
 // ConnectPostgres initializes a connection to PG, and returns errors if any
@@ -107,11 +109,12 @@ func Entrypoint(ctx context.Context, cfg config.Configuration, connections boots
 		startDelay := 0 * time.Second
 
 		var (
-			pipeline       = datapipe.NewPipeline(ctx, cfg, connections.RDMS, connections.Graph, graphQueryCache, ingestSchema)
+			cl             = changelog.NewChangelog(connections.Graph, connections.RDMS, changelog.DefaultOptions())
+			pipeline       = datapipe.NewPipeline(ctx, cfg, connections.RDMS, connections.Graph, graphQueryCache, ingestSchema, cl)
 			graphQuery     = queries.NewGraphQuery(connections.Graph, graphQueryCache, cfg)
 			authorizer     = auth.NewAuthorizer(connections.RDMS)
 			datapipeDaemon = datapipe.NewDaemon(pipeline, startDelay, time.Duration(cfg.DatapipeInterval)*time.Second, connections.RDMS)
-			routerInst     = router.NewRouter(cfg, authorizer, bootstrap.ContentSecurityPolicy)
+			routerInst     = router.NewRouter(cfg, authorizer, fmt.Sprintf(bootstrap.ContentSecurityPolicy, "", ""))
 			ctxInitializer = database.NewContextInitializer(connections.RDMS)
 			authenticator  = api.NewAuthenticator(cfg, connections.RDMS, ctxInitializer)
 		)
@@ -132,6 +135,7 @@ func Entrypoint(ctx context.Context, cfg config.Configuration, connections boots
 		return []daemons.Daemon{
 			bhapi.NewDaemon(cfg, routerInst.Handler()),
 			gc.NewDataPruningDaemon(connections.RDMS),
+			cl,
 			datapipeDaemon,
 		}, nil
 	}
