@@ -18,9 +18,6 @@ import * as bhSharedUI from 'bh-shared-ui';
 import { FlatGraphResponse, GraphResponse } from 'js-client-library';
 import { normalizeGraphDataForSigma } from '.';
 
-const transformToFlatGraphResponseSpy = vitest.spyOn(bhSharedUI, 'transformToFlatGraphResponse');
-transformToFlatGraphResponseSpy.mockReturnValue({});
-
 const typicalGraphResponse: GraphResponse = {
     data: {
         nodes: {},
@@ -28,6 +25,9 @@ const typicalGraphResponse: GraphResponse = {
     },
 };
 
+const transformFlatGraphResponseSpy = vi.spyOn(bhSharedUI, 'transformFlatGraphResponse');
+transformFlatGraphResponseSpy.mockReturnValue(typicalGraphResponse.data);
+
 const typicalFlatGraphResponse: FlatGraphResponse = {
     '1234': {
         color: '#DBE617',
@@ -61,13 +61,13 @@ describe('normalizeGraphDataForSigma', () => {
         expect(actual).toBeUndefined();
     });
 
-    it('calls transformToFlatGraphResponse when graphData matches GraphResponse interface', () => {
+    it('returns graphData as is if it doesnt match the GraphResponse interface', () => {
         normalizeGraphDataForSigma(typicalGraphResponse);
-        expect(transformToFlatGraphResponseSpy).toBeCalled();
+        expect(transformFlatGraphResponseSpy).not.toBeCalled();
     });
 
-    it('returns graphData as is if it doesnt match the GraphResponse interface', () => {
+    it('calls transformToFlatGraphResponse when graphData matches GraphResponse interface', () => {
         normalizeGraphDataForSigma(typicalFlatGraphResponse);
-        expect(transformToFlatGraphResponseSpy).not.toBeCalled();
+        expect(transformFlatGraphResponseSpy).toBeCalled();
     });
 });
