@@ -15,15 +15,14 @@
 // SPDX-License-Identifier: Apache-2.0
 
 import { Theme } from '@mui/material';
-import { GetIconInfo, GlyphKind, IconDictionary } from 'bh-shared-ui';
+import { GLYPHS, GetIconInfo, GlyphKind, IconDictionary, getGlyphFromKinds } from 'bh-shared-ui';
 import { MultiDirectedGraph } from 'graphology';
 import { random } from 'graphology-layout';
 import forceAtlas2 from 'graphology-layout-forceatlas2';
-import { GraphData, GraphEdges, GraphNodes } from 'js-client-library';
+import { GraphData, GraphEdge, GraphEdges, GraphNodes } from 'js-client-library';
 import { RankDirection, layoutDagre } from 'src/hooks/useLayoutDagre/useLayoutDagre';
 import { GlyphLocation } from 'src/rendering/programs/node.glyphs';
 import { EdgeDirection, EdgeParams, NodeParams, ThemedOptions } from 'src/utils';
-import { GLYPHS } from './svgIcons';
 
 export const standardLayout = (graph: MultiDirectedGraph) => {
     forceAtlas2.assign(graph, {
@@ -49,15 +48,20 @@ export const sequentialLayout = (graph: MultiDirectedGraph) => {
     assignDagre();
 };
 
-export const initGraph = (
-    graph: MultiDirectedGraph,
-    items: GraphData,
-    theme: Theme,
-    darkMode: boolean,
-    customIcons: IconDictionary,
-    hideNodes: boolean
-) => {
+type GraphOptions = {
+    theme: Theme;
+    darkMode: boolean;
+    customIcons: IconDictionary;
+    hideNodes: boolean;
+    tagGlyphMap: Record<string, string>;
+    themedOptions?: ThemedOptions;
+};
+
+export const initGraph = (items: GraphData, options: GraphOptions) => {
+    const graph = new MultiDirectedGraph();
+
     const { nodes, edges } = items;
+    const { theme, darkMode } = options;
 
     const themedOptions = {
         labels: {
@@ -77,22 +81,24 @@ export const initGraph = (
         },
     };
 
-    initGraphNodes(graph, nodes, themedOptions, customIcons, hideNodes);
+    initGraphNodes(graph, nodes, { ...options, themedOptions });
     initGraphEdges(graph, edges, themedOptions);
 
     random.assign(graph, { scale: 1000 });
 
     // RUN DEFAULT LAYOUT
     sequentialLayout(graph);
+
+    return graph;
 };
 
 const initGraphNodes = (
     graph: MultiDirectedGraph,
     nodes: GraphNodes,
-    themedOptions: ThemedOptions,
-    customIcons: IconDictionary,
-    hideNodes: boolean
+    options: GraphOptions & { themedOptions: ThemedOptions }
 ) => {
+    const { themedOptions, customIcons, hideNodes, tagGlyphMap } = options;
+
     Object.keys(nodes).forEach((key: string) => {
         const node = nodes[key];
         // Set default node parameters
@@ -104,11 +110,21 @@ const initGraphNodes = (
             ...themedOptions.labels,
         };
 
-        const icon = GetIconInfo(node.kind, customIcons);
-        nodeParams.color = icon.color;
-        nodeParams.image = icon.url || '';
+        const iconInfo = GetIconInfo(node.kind, customIcons);
+        nodeParams.color = iconInfo.color;
+        nodeParams.image = iconInfo.url || '';
         nodeParams.glyphs = [];
 
+        const glyphImage = getGlyphFromKinds(node.kinds, tagGlyphMap);
+        if (glyphImage) {
+            nodeParams.type = 'glyphs';
+            nodeParams.glyphs.push({
+                location: GlyphLocation.TOP_RIGHT,
+                image: glyphImage,
+                ...themedOptions.glyph.colors,
+            });
+        }
+
         // Tier zero nodes should be marked with a gem glyph
         if (node.isTierZero) {
             nodeParams.type = 'glyphs';
@@ -118,6 +134,7 @@ const initGraphNodes = (
                 ...themedOptions.glyph.colors,
             });
         }
+
         if (node.isOwnedObject) {
             nodeParams.type = 'glyphs';
             nodeParams.glyphs.push({
@@ -137,14 +154,20 @@ const initGraphNodes = (
 
 const initGraphEdges = (graph: MultiDirectedGraph, edges: GraphEdges, themedOptions: ThemedOptions) => {
     // Group edges with the same start and end nodes into arrays. Should be grouped regardless of direction
+    const lookupSet = new Set<string>();
     const groupedEdges = edges.reduce<Record<string, GraphEdges>>((groups, edge) => {
-        const identifiers = [edge.source, edge.target].sort();
-        const id = `${identifiers[0]}_${identifiers[1]}`;
+        const groupKey = getEdgeGroupKey(edge);
+        const edgeKey = getEdgeKey(edge);
 
-        if (!groups[id]) {
-            groups[id] = [];
+        if (!groups[groupKey]) {
+            groups[groupKey] = [];
+        }
+
+        // Dedupe edges before they are added to groups so that curved edges get counted and rendered correctly
+        if (!lookupSet.has(edgeKey)) {
+            lookupSet.add(edgeKey);
+            groups[groupKey].push(edge);
         }
-        groups[id].push(edge);
 
         return groups;
     }, {});
@@ -154,7 +177,7 @@ const initGraphEdges = (graph: MultiDirectedGraph, edges: GraphEdges, themedOpti
         const groupSize = groupedEdges[group].length;
 
         for (const [i, edge] of groupedEdges[group].entries()) {
-            const key = `${edge.source}_${edge.kind}_${edge.target}`;
+            const key = getEdgeKey(edge);
 
             // Set default values for single edges
             const edgeParams: Partial<EdgeParams> = {
@@ -193,3 +216,12 @@ const initGraphEdges = (graph: MultiDirectedGraph, edges: GraphEdges, themedOpti
         }
     }
 };
+
+const getEdgeKey = (edge: GraphEdge) => {
+    return `${edge.source}_${edge.kind}_${edge.target}`;
+};
+
+const getEdgeGroupKey = (edge: GraphEdge) => {
+    const identifiers = [edge.source, edge.target].sort();
+    return `${identifiers[0]}_${identifiers[1]}`;
+};
