@@ -35,45 +35,6 @@ import (
 	"github.com/specterops/dawgs/util/channels"
 )
 
-func PostProcessedRelationships() []graph.Kind {
-	return []graph.Kind{
-		ad.DCSync,
-		ad.SyncLAPSPassword,
-		ad.CanRDP,
-		ad.AdminTo,
-		ad.CanPSRemote,
-		ad.ExecuteDCOM,
-		ad.TrustedForNTAuth,
-		ad.IssuedSignedBy,
-		ad.EnterpriseCAFor,
-		ad.GoldenCert,
-		ad.ADCSESC1,
-		ad.ADCSESC3,
-		ad.ADCSESC4,
-		ad.ADCSESC6a,
-		ad.ADCSESC6b,
-		ad.ADCSESC10a,
-		ad.ADCSESC10b,
-		ad.ADCSESC9a,
-		ad.ADCSESC9b,
-		ad.ADCSESC13,
-		ad.EnrollOnBehalfOf,
-		ad.SyncedToEntraUser,
-		ad.Owns,
-		ad.WriteOwner,
-		ad.ExtendedByPolicy,
-		ad.Owns,
-		ad.WriteOwner,
-		ad.CoerceAndRelayNTLMToADCS,
-		ad.CoerceAndRelayNTLMToSMB,
-		ad.CoerceAndRelayNTLMToLDAP,
-		ad.CoerceAndRelayNTLMToLDAPS,
-		ad.GPOAppliesTo,
-		ad.CanApplyGPO,
-		ad.HasTrustKeys,
-	}
-}
-
 func PostSyncLAPSPassword(ctx context.Context, db graph.Database, groupExpansions impact.PathAggregator) (*analysis.AtomicPostProcessingStats, error) {
 	if domainNodes, err := fetchCollectedDomainNodes(ctx, db); err != nil {
 		return &analysis.AtomicPostProcessingStats{}, err
@@ -141,6 +102,44 @@ func PostDCSync(ctx context.Context, db graph.Database, groupExpansions impact.P
 	}
 }
 
+func PostProtectAdminGroups(ctx context.Context, db graph.Database) (*analysis.AtomicPostProcessingStats, error) {
+	domainNodes, err := fetchCollectedDomainNodes(ctx, db)
+	if err != nil {
+		return &analysis.AtomicPostProcessingStats{}, err
+	}
+
+	operation := analysis.NewPostRelationshipOperation(ctx, db, "ProtectAdminGroups Post Processing")
+
+	for _, domain := range domainNodes {
+
+		operation.Operation.SubmitReader(func(ctx context.Context, tx graph.Transaction, outC chan<- analysis.CreatePostRelationshipJob) error {
+			if adminSDHolderIDs, err := getAdminSDHolder(tx, domain); graph.IsErrNotFound(err) {
+				// No AdminSDHolder IDs found for this domain
+				return nil
+			} else if err != nil {
+				return err
+			} else if len(adminSDHolderIDs) == 0 {
+				// No AdminSDHolder IDs found for this domain
+				return nil
+			} else if protectedObjectIDs, err := getAdminSDHolderProtected(tx, domain); err != nil {
+				return err
+			} else {
+				fromID := adminSDHolderIDs[0] // AdminSDHolder should be unique per domain
+				for _, toID := range protectedObjectIDs {
+					channels.Submit(ctx, outC, analysis.CreatePostRelationshipJob{
+						FromID: fromID,
+						ToID:   toID,
+						Kind:   ad.ProtectAdminGroups,
+					})
+				}
+				return nil
+			}
+		})
+	}
+
+	return &operation.Stats, operation.Done()
+}
+
 func PostHasTrustKeys(ctx context.Context, db graph.Database) (*analysis.AtomicPostProcessingStats, error) {
 	if domainNodes, err := fetchCollectedDomainNodes(ctx, db); err != nil {
 		return &analysis.AtomicPostProcessingStats{}, err
@@ -308,6 +307,35 @@ func getLAPSComputersForDomain(tx graph.Transaction, domain *graph.Node) ([]grap
 	}
 }
 
+func getAdminSDHolder(tx graph.Transaction, domain *graph.Node) ([]graph.ID, error) {
+	if domainSid, err := domain.Properties.Get(ad.DomainSID.String()).String(); err != nil {
+		return nil, err
+	} else {
+		return ops.FetchNodeIDs(tx.Nodes().Filterf(func() graph.Criteria {
+			return query.And(
+				query.KindIn(query.Node(), ad.Container),
+				query.StringStartsWith(query.NodeProperty(ad.DistinguishedName.String()), AdminSDHolderDNPrefix),
+				query.Equals(query.NodeProperty(ad.DomainSID.String()), domainSid),
+			)
+		}))
+	}
+}
+
+func getAdminSDHolderProtected(tx graph.Transaction, domain *graph.Node) ([]graph.ID, error) {
+	if domainSid, err := domain.Properties.Get(ad.DomainSID.String()).String(); err != nil {
+		return nil, err
+	} else {
+		return ops.FetchNodeIDs(tx.Nodes().Filterf(func() graph.Criteria {
+			return query.And(
+				query.KindIn(query.Node(), ad.Computer, ad.User, ad.Group),
+				query.Equals(
+					query.Property(query.Node(), ad.AdminSDHolderProtected.String()), true),
+				query.Equals(query.Property(query.Node(), ad.DomainSID.String()), domainSid),
+			)
+		}))
+	}
+}
+
 func PostLocalGroups(ctx context.Context, db graph.Database, localGroupExpansions impact.PathAggregator, enforceURA bool, citrixEnabled bool) (*analysis.AtomicPostProcessingStats, error) {
 	var (
 		adminGroupSuffix    = "-544"
