@@ -17,7 +17,7 @@
 package azure
 
 import (
-	"github.com/specterops/bloodhound/dawgs/graph"
+	"github.com/specterops/dawgs/graph"
 )
 
 func CompositeAssetKinds() []graph.Kind {
