@@ -20,6 +20,7 @@ import (
 	"errors"
 	"flag"
 	"fmt"
+	"log/slog"
 	"os"
 	"path/filepath"
 
@@ -77,13 +78,19 @@ func (s *command) Parse(cmdIndex int) error {
 
 // Run analysis command
 func (s *command) Run() error {
-	if paths, err := workspace.FindPaths(s.env); err != nil {
+	paths, err := workspace.FindPaths(s.env)
+	if err != nil {
 		return fmt.Errorf("finding workspace root: %w", err)
-	} else if err := analyzers.Run(paths, s.env, s.outputAllSeverity); errors.Is(err, analyzers.ErrSeverityExit) {
-		return err
+	}
+
+	err = analyzers.Run(paths, s.env, s.outputAllSeverity)
+	if errors.Is(err, analyzers.ErrSeverityExit) {
+		return fmt.Errorf("analyzers found high severity: %w", err)
+	} else if errors.Is(err, analyzers.ErrWarnExit) {
+		slog.Warn("Analysis completed with warnings. Rerun with `-all` to see results.")
 	} else if err != nil {
 		return fmt.Errorf("analyzers incomplete: %w", err)
-	} else {
-		return nil
 	}
+
+	return nil
 }
