@@ -31,7 +31,12 @@ import (
 )
 
 func main() {
-	env := environment.NewEnvironment()
+	env, err := environment.NewEnvironment()
+	if err != nil {
+		slog.Error(fmt.Sprintf("Could not init environment: %v", err))
+		os.Exit(1)
+	}
+
 	var rawLvl = env[environment.LogLevelVarName]
 
 	bhlog.ConfigureDefaultText(os.Stderr)
