@@ -19,12 +19,7 @@ import { BasePath, BaseSVG, BaseSVGProps } from './utils';
 
 export const DataAlert: React.FC<BaseSVGProps> = (props) => {
     return (
-        <BaseSVG
-            name='file-magnifying-glass'
-            xmlns='http://www.w3.org/2000/svg'
-            viewBox='0 0 18 22'
-            fill='none'
-            {...props}>
+        <BaseSVG name='data-alert' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 18 22' fill='none' {...props}>
             <BasePath
                 d='M18 2H10L4.02 8L4 20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V4C20 2.9 19.1 2 18 2ZM18 20H6V8.83L10.83 4H18V20Z'
                 stroke='#ED8537'
