@@ -20,13 +20,13 @@ import { FC } from 'react';
 const References: FC = () => {
     return (
         <Box sx={{ overflowX: 'auto' }}>
-            <Link target='_blank' rel='noopener' href='https://github.com/BloodHoundAD/BARK'>
+            <Link target='_blank' rel='noopener noreferrer' href='https://github.com/BloodHoundAD/BARK'>
                 Andy Robbins - BARK.ps1
             </Link>
             <br />
             <Link
                 target='_blank'
-                rel='noopener'
+                rel='noopener noreferrer'
                 href='https://www.netspi.com/blog/technical/cloud-penetration-testing/extract-credentials-from-azure-kubernetes-service/'>
                 Karl Fosaaen - How To Extract Credentials from Azure Kubernetes Service (AKS)
             </Link>
