@@ -23,7 +23,10 @@ const Opsec: FC = () => {
             <Typography variant='body2'>
                 NTLM relayed authentications can be detected by login events where the IP address does not match the
                 computer’s actual IP address. This detection technique is described in the blog post:{' '}
-                <a href={'https://posts.bluraven.io/detecting-ntlm-relay-attacks-d92e99e68fb9'}>
+                <a
+                    target='_blank'
+                    rel='noopener noreferrer'
+                    href={'https://posts.bluraven.io/detecting-ntlm-relay-attacks-d92e99e68fb9'}>
                     Detecting NTLM Relay Attacks
                 </a>
                 .
