@@ -20,11 +20,11 @@ import { FC } from 'react';
 const References: FC = () => {
     return (
         <Box sx={{ overflowX: 'auto' }}>
-            <Link target='_blank' rel='noopener' href=''></Link>
+            <Link target='_blank' rel='noopener noreferrer' href=''></Link>
             <br />
-            <Link target='_blank' rel='noopener' href=''></Link>
+            <Link target='_blank' rel='noopener noreferrer' href=''></Link>
             <br />
-            <Link target='_blank' rel='noopener' href=''></Link>
+            <Link target='_blank' rel='noopener noreferrer' href=''></Link>
         </Box>
     );
 };
