@@ -22,27 +22,27 @@ const References: FC = () => {
         <Box sx={{ overflowX: 'auto' }}>
             <Link
                 target='_blank'
-                rel='noopener'
+                rel='noopener noreferrer'
                 href='https://specterops.io/wp-content/uploads/sites/3/2022/06/Certified_Pre-Owned.pdf'>
                 https://specterops.io/wp-content/uploads/sites/3/2022/06/Certified_Pre-Owned.pdf
             </Link>
             <br />
             <Link
                 target='_blank'
-                rel='noopener'
+                rel='noopener noreferrer'
                 href='https://github.com/GhostPack/Certify/wiki/3-%E2%80%90-Domain-Persistence-Techniques#dpersist1---forging-certificates-with-stolen-ca-certificates'>
                 https://github.com/GhostPack/Certify/wiki/3-%E2%80%90-Domain-Persistence-Techniques#dpersist1---forging-certificates-with-stolen-ca-certificates
             </Link>
             <br />
-            <Link target='_blank' rel='noopener' href='https://github.com/GhostPack/Certify'>
+            <Link target='_blank' rel='noopener noreferrer' href='https://github.com/GhostPack/Certify'>
                 https://github.com/GhostPack/Certify
             </Link>
             <br />
-            <Link target='_blank' rel='noopener' href='https://github.com/GhostPack/Rubeus'>
+            <Link target='_blank' rel='noopener noreferrer' href='https://github.com/GhostPack/Rubeus'>
                 https://github.com/GhostPack/Rubeus
             </Link>
             <br />
-            <Link target='_blank' rel='noopener' href='https://github.com/ly4k/Certipy#golden-certificates'>
+            <Link target='_blank' rel='noopener noreferrer' href='https://github.com/ly4k/Certipy#golden-certificates'>
                 https://github.com/ly4k/Certipy#golden-certificates
             </Link>
         </Box>
