@@ -20,13 +20,13 @@ import { FC } from 'react';
 const References: FC = () => {
     return (
         <Box sx={{ overflowX: 'auto' }}>
-            <Link target='_blank' rel='noopener' href='https://adsecurity.org/?tag=ad-delegation'>
+            <Link target='_blank' rel='noopener noreferrer' href='https://adsecurity.org/?tag=ad-delegation'>
                 https://adsecurity.org/?tag=ad-delegation
             </Link>
             <br />
             <Link
                 target='_blank'
-                rel='noopener'
+                rel='noopener noreferrer'
                 href='https://www.itprotoday.com/management-mobility/view-or-remove-active-directory-delegated-permissions '>
                 https://www.itprotoday.com/management-mobility/view-or-remove-active-directory-delegated-permissions{' '}
             </Link>
