@@ -65,7 +65,10 @@ const LinuxAbuse: FC<EdgeInfoProps & { haslaps: boolean }> = ({ sourceName, targ
 
                     <Typography variant='body2'>
                         It can also be done with pass-the-hash using{' '}
-                        <Link target='_blank' rel='noopener' href='https://github.com/byt3bl33d3r/pth-toolkit'>
+                        <Link
+                            target='_blank'
+                            rel='noopener noreferrer'
+                            href='https://github.com/byt3bl33d3r/pth-toolkit'>
                             pth-toolkit's net tool
                         </Link>
                         . If the LM hash is not known, use 'ffffffffffffffffffffffffffffffff'.
@@ -141,7 +144,10 @@ const LinuxAbuse: FC<EdgeInfoProps & { haslaps: boolean }> = ({ sourceName, targ
 
                     <Typography variant='body2'>
                         A targeted kerberoast attack can be performed using{' '}
-                        <Link target='_blank' rel='noopener' href='https://github.com/ShutdownRepo/targetedKerberoast'>
+                        <Link
+                            target='_blank'
+                            rel='noopener noreferrer'
+                            href='https://github.com/ShutdownRepo/targetedKerberoast'>
                             targetedKerberoast.py
                         </Link>
                         .
@@ -177,7 +183,10 @@ const LinuxAbuse: FC<EdgeInfoProps & { haslaps: boolean }> = ({ sourceName, targ
 
                     <Typography variant='body2'>
                         It can also be done with pass-the-hash using{' '}
-                        <Link target='_blank' rel='noopener' href='https://github.com/byt3bl33d3r/pth-toolkit'>
+                        <Link
+                            target='_blank'
+                            rel='noopener noreferrer'
+                            href='https://github.com/byt3bl33d3r/pth-toolkit'>
                             pth-toolkit's net tool
                         </Link>
                         . If the LM hash is not known, use 'ffffffffffffffffffffffffffffffff'.
@@ -199,7 +208,10 @@ const LinuxAbuse: FC<EdgeInfoProps & { haslaps: boolean }> = ({ sourceName, targ
 
                     <Typography variant='body2'>
                         To abuse this permission, use{' '}
-                        <Link target='_blank' rel='noopener' href='https://github.com/ShutdownRepo/pywhisker'>
+                        <Link
+                            target='_blank'
+                            rel='noopener noreferrer'
+                            href='https://github.com/ShutdownRepo/pywhisker'>
                             pyWhisker
                         </Link>
                         .
@@ -326,7 +338,10 @@ const LinuxAbuse: FC<EdgeInfoProps & { haslaps: boolean }> = ({ sourceName, targ
                         <Typography variant='body1'> Shadow Credentials attack </Typography>
                         <Typography variant='body2'>
                             To abuse this permission, use{' '}
-                            <Link target='_blank' rel='noopener' href='https://github.com/ShutdownRepo/pywhisker'>
+                            <Link
+                                target='_blank'
+                                rel='noopener noreferrer'
+                                href='https://github.com/ShutdownRepo/pywhisker'>
                                 pyWhisker
                             </Link>
                             .
@@ -407,7 +422,10 @@ const LinuxAbuse: FC<EdgeInfoProps & { haslaps: boolean }> = ({ sourceName, targ
                         <Typography variant='body1'> Shadow Credentials attack </Typography>
                         <Typography variant='body2'>
                             To abuse this permission, use{' '}
-                            <Link target='_blank' rel='noopener' href='https://github.com/ShutdownRepo/pywhisker'>
+                            <Link
+                                target='_blank'
+                                rel='noopener noreferrer'
+                                href='https://github.com/ShutdownRepo/pywhisker'>
                                 pyWhisker
                             </Link>
                             .
@@ -520,13 +538,13 @@ const LinuxAbuse: FC<EdgeInfoProps & { haslaps: boolean }> = ({ sourceName, targ
 
                     <Typography variant='body2'>
                         From a Linux machine, the gPLink manipulation attack vector may be exploited using the{' '}
-                        <Link target='_blank' rel='noopener' href='https://github.com/synacktiv/OUned'>
+                        <Link target='_blank' rel='noopener noreferrer' href='https://github.com/synacktiv/OUned'>
                             OUned.py
                         </Link>{' '}
                         tool. For a detailed outline of exploit requirements and implementation, you can refer to{' '}
                         <Link
                             target='_blank'
-                            rel='noopener'
+                            rel='noopener noreferrer'
                             href='https://www.synacktiv.com/publications/ounedpy-exploiting-hidden-organizational-units-acl-attack-vectors-in-active-directory'>
                             the article associated to the OUned.py tool
                         </Link>
@@ -593,7 +611,7 @@ const LinuxAbuse: FC<EdgeInfoProps & { haslaps: boolean }> = ({ sourceName, targ
                     </Typography>
 
                     <Typography variant='body2'>
-                        <Link target='_blank' rel='noopener' href='https://github.com/Hackndo/pyGPOAbuse'>
+                        <Link target='_blank' rel='noopener noreferrer' href='https://github.com/Hackndo/pyGPOAbuse'>
                             pyGPOAbuse.py
                         </Link>{' '}
                         can be used for that purpose.
@@ -678,13 +696,13 @@ const LinuxAbuse: FC<EdgeInfoProps & { haslaps: boolean }> = ({ sourceName, targ
 
                     <Typography variant='body2'>
                         From a Linux machine, the gPLink manipulation attack vector may be exploited using the{' '}
-                        <Link target='_blank' rel='noopener' href='https://github.com/synacktiv/OUned'>
+                        <Link target='_blank' rel='noopener noreferrer' href='https://github.com/synacktiv/OUned'>
                             OUned.py
                         </Link>{' '}
                         tool. For a detailed outline of exploit requirements and implementation, you can refer to{' '}
                         <Link
                             target='_blank'
-                            rel='noopener'
+                            rel='noopener noreferrer'
                             href='https://www.synacktiv.com/publications/ounedpy-exploiting-hidden-organizational-units-acl-attack-vectors-in-active-directory'>
                             the article associated to the OUned.py tool
                         </Link>
