@@ -19,7 +19,13 @@ import { rest } from 'msw';
 import { setupServer } from 'msw/node';
 import { PERSIST_NOTIFICATION } from '../../providers';
 import { renderHook, waitFor } from '../../test-utils';
-import { FETCH_ERROR_KEY, FETCH_ERROR_MESSAGE, NO_PERMISSION_KEY, NO_PERMISSION_MESSAGE, apiClient } from '../../utils';
+import {
+    FINISHED_JOBS_FETCH_ERROR_KEY,
+    FINISHED_JOBS_FETCH_ERROR_MESSAGE,
+    FINISHED_JOBS_NO_PERMISSION_KEY,
+    FINISHED_JOBS_NO_PERMISSION_MESSAGE,
+    apiClient,
+} from '../../utils';
 import { useFinishedJobs } from './useFinishedJobs';
 
 const addNotificationMock = vi.fn();
@@ -128,8 +134,8 @@ describe('useFinishedJobs', () => {
         await waitFor(() => expect(result.current.isLoading).toBe(false));
 
         expect(addNotificationMock).toHaveBeenCalledWith(
-            NO_PERMISSION_MESSAGE,
-            NO_PERMISSION_KEY,
+            FINISHED_JOBS_NO_PERMISSION_MESSAGE,
+            FINISHED_JOBS_NO_PERMISSION_KEY,
             PERSIST_NOTIFICATION
         );
     });
@@ -147,13 +153,16 @@ describe('useFinishedJobs', () => {
         const { result } = renderHook(() => useFinishedJobs({ page: 0, rowsPerPage: 10 }));
         await waitFor(() => expect(result.current.isLoading).toBe(false));
 
-        expect(addNotificationMock).toHaveBeenCalledWith(FETCH_ERROR_MESSAGE, FETCH_ERROR_KEY);
+        expect(addNotificationMock).toHaveBeenCalledWith(
+            FINISHED_JOBS_FETCH_ERROR_MESSAGE,
+            FINISHED_JOBS_FETCH_ERROR_KEY
+        );
     });
 
     it('dismisses the "no permission" notification on unmount', async () => {
         checkPermissionMock.mockImplementation(() => false);
         const { unmount } = renderHook(() => useFinishedJobs({ page: 0, rowsPerPage: 10 }));
         unmount();
-        expect(dismissNotificationMock).toHaveBeenCalledWith(NO_PERMISSION_KEY);
+        expect(dismissNotificationMock).toHaveBeenCalledWith(FINISHED_JOBS_NO_PERMISSION_KEY);
     });
 });
