@@ -31,17 +31,22 @@ import {
     Skeleton,
     Switch,
     Textarea,
+    Tooltip,
 } from '@bloodhoundenterprise/doodleui';
-import { faTrashCan } from '@fortawesome/free-solid-svg-icons';
+import { IconName, faTrashCan } from '@fortawesome/free-solid-svg-icons';
 import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
+import clsx from 'clsx';
 import {
+    AssetGroupTag,
     AssetGroupTagTypeLabel,
     AssetGroupTagTypeZone,
     CreateAssetGroupTagRequest,
     UpdateAssetGroupTagRequest,
 } from 'js-client-library';
+import isEmpty from 'lodash/isEmpty';
 import { FC, useCallback, useContext, useEffect, useState } from 'react';
 import { SubmitHandler, useForm } from 'react-hook-form';
+import { AppIcon } from '../../../../components';
 import DeleteConfirmationDialog from '../../../../components/DeleteConfirmationDialog';
 import {
     useAssetGroupTagInfo,
@@ -50,27 +55,29 @@ import {
     useDeleteAssetGroupTag,
     usePatchAssetGroupTag,
 } from '../../../../hooks/useAssetGroupTags';
-import { usePZPathParams } from '../../../../hooks/useZoneParams';
 import { useNotifications } from '../../../../providers';
 import { useAppNavigate } from '../../../../utils';
 import { PrivilegeZonesContext } from '../../PrivilegeZonesContext';
 import { handleError } from '../utils';
+import GlyphSelectDialog from './GlyphSelectDialog';
 import { useTagFormUtils } from './utils';
 
 const MAX_NAME_LENGTH = 250;
 
 export const TagForm: FC = () => {
+    const [glyphDialogOpen, setGlyphDialogOpen] = useState(false);
     const [deleteDialogOpen, setDeleteDialogOpen] = useState(false);
 
     const navigate = useAppNavigate();
     const { addNotification } = useNotifications();
 
-    const { tagId } = usePZPathParams();
     const {
+        tagId,
         privilegeZoneAnalysisEnabled,
         disableNameInput,
         isLabelPage,
         isUpdateZoneLocation,
+        isZonePage,
         showAnalysisToggle,
         showDeleteButton,
         formTitle,
@@ -85,20 +92,45 @@ export const TagForm: FC = () => {
     const tagsQuery = useAssetGroupTags();
     const tagQuery = useAssetGroupTagInfo(tagId);
 
-    const { ZoneList, SalesMessage } = useContext(PrivilegeZonesContext);
+    const { ZoneList, SalesMessage, Certification } = useContext(PrivilegeZonesContext);
     const showSalesMessage = isUpdateZoneLocation && SalesMessage;
     const showZoneList = isUpdateZoneLocation && ZoneList;
 
+    const diffValues = (
+        data: AssetGroupTag | undefined,
+        formValues: UpdateAssetGroupTagRequest,
+        isLabelPage: boolean
+    ): Partial<UpdateAssetGroupTagRequest> => {
+        if (data === undefined) return formValues;
+        const workingCopy = { ...formValues };
+        const diffed: Partial<UpdateAssetGroupTagRequest> = {};
+
+        if (data.name !== workingCopy.name) diffed.name = workingCopy.name;
+        if (data.description !== workingCopy.description) diffed.description = workingCopy.description;
+
+        // return early so as not to set values specific to zones
+        if (isLabelPage) return diffed;
+
+        if (data.position !== workingCopy.position) diffed.position = workingCopy.position;
+        if (data.require_certify != workingCopy.require_certify) diffed.require_certify = workingCopy.require_certify;
+        if (data.analysis_enabled !== workingCopy.analysis_enabled)
+            diffed.analysis_enabled = workingCopy.analysis_enabled;
+        if (data.glyph != workingCopy.glyph) diffed.glyph = workingCopy.glyph;
+
+        return diffed;
+    };
+
     const form = useForm<UpdateAssetGroupTagRequest>({
         defaultValues: {
             name: '',
             description: '',
-            analysis_enabled: false,
             position: -1,
+            require_certify: false,
+            analysis_enabled: false,
+            glyph: '',
         },
     });
 
-    const { isDirty, dirtyFields } = form.formState;
     const { control, getValues, handleSubmit, reset, setValue } = form;
 
     const createTagMutation = useCreateAssetGroupTag();
@@ -108,12 +140,14 @@ export const TagForm: FC = () => {
     const handleCreateTag = useCallback(
         async (formData: CreateAssetGroupTagRequest) => {
             try {
-                const requestValues = {
+                const requestValues: CreateAssetGroupTagRequest = {
                     name: formData.name,
                     description: formData.description,
+                    require_certify: isZonePage ? formData.require_certify : null,
                     position: null,
                     type: isLabelPage ? AssetGroupTagTypeLabel : AssetGroupTagTypeZone,
                 };
+                if (formData.glyph !== '') requestValues.glyph = formData.glyph;
 
                 const response = await createTagMutation.mutateAsync({
                     values: requestValues,
@@ -128,36 +162,23 @@ export const TagForm: FC = () => {
                 handleError(error, 'creating', tagType, addNotification);
             }
         },
-        [createTagMutation, addNotification, handleCreateNavigate, tagType, tagTypeDisplay, isLabelPage]
+        [isZonePage, isLabelPage, createTagMutation, addNotification, tagTypeDisplay, handleCreateNavigate, tagType]
     );
 
     const handleUpdateTag = useCallback(
-        async (
-            dirtyFields: Partial<
-                Readonly<{
-                    name?: boolean | undefined;
-                    description?: boolean | undefined;
-                    type?: boolean | undefined;
-                    position?: boolean | undefined;
-                    requireCertify?: boolean | undefined;
-                    analysis_enabled?: boolean | undefined;
-                }>
-            >
-        ) => {
+        async (formData: UpdateAssetGroupTagRequest) => {
             try {
-                if (!isDirty) {
+                const diffedValues = diffValues(tagQuery.data, formData, isLabelPage);
+                if (isEmpty(diffedValues)) {
                     addNotification('No changes detected', `privilege-zones_update-tag_no-changes-warn_${tagId}`, {
                         anchorOrigin: { vertical: 'top', horizontal: 'right' },
                     });
                     return;
                 }
 
-                const updatedValues = Object.keys(dirtyFields).reduce((acc: any, key) => {
-                    acc[key] = getValues(key as keyof UpdateAssetGroupTagRequest);
-                    return acc;
-                }, {});
+                const updatedValues = { ...diffedValues };
 
-                if (!privilegeZoneAnalysisEnabled || isLabelPage) delete updatedValues.analysis_enabled;
+                if (!privilegeZoneAnalysisEnabled) delete updatedValues.analysis_enabled;
 
                 await updateTagMutation.mutateAsync({
                     updatedValues,
@@ -178,16 +199,15 @@ export const TagForm: FC = () => {
             }
         },
         [
-            tagId,
-            handleUpdateNavigate,
-            addNotification,
-            updateTagMutation,
-            tagType,
-            tagTypeDisplay,
-            isDirty,
+            tagQuery.data,
             privilegeZoneAnalysisEnabled,
             isLabelPage,
-            getValues,
+            updateTagMutation,
+            tagId,
+            addNotification,
+            tagTypeDisplay,
+            tagType,
+            handleUpdateNavigate,
         ]
     );
 
@@ -215,13 +235,21 @@ export const TagForm: FC = () => {
             if (tagId === '') {
                 handleCreateTag(formData as CreateAssetGroupTagRequest);
             } else {
-                handleUpdateTag(dirtyFields);
+                handleUpdateTag(formData);
             }
         },
-        [tagId, handleCreateTag, handleUpdateTag, dirtyFields]
+        [tagId, handleCreateTag, handleUpdateTag]
     );
 
-    const handleCancel = useCallback(() => setDeleteDialogOpen(false), []);
+    const handleDeleteCancel = useCallback(() => setDeleteDialogOpen(false), []);
+
+    const handleGlyphCancel = useCallback(() => setGlyphDialogOpen(false), []);
+    const handleGlyphSelect = useCallback((iconName?: IconName) => {
+        if (iconName) setValue('glyph', iconName, { shouldDirty: true });
+        else setValue('glyph', '', { shouldDirty: true });
+
+        setGlyphDialogOpen(false);
+    }, []);
 
     useEffect(() => {
         if (tagQuery.data) {
@@ -229,7 +257,9 @@ export const TagForm: FC = () => {
                 name: tagQuery.data.name,
                 description: tagQuery.data.description,
                 position: tagQuery.data.position,
+                require_certify: tagQuery.data.require_certify || false,
                 analysis_enabled: tagQuery.data.analysis_enabled || false,
+                glyph: tagQuery.data.glyph === null ? '' : tagQuery.data.glyph,
             });
         }
     }, [tagQuery.data, reset]);
@@ -256,12 +286,24 @@ export const TagForm: FC = () => {
                                     <Label>Description</Label>
                                     <Skeleton className='h-16 w-full' />
                                 </div>
+                                {isZonePage && Certification && (
+                                    <div className='grid gap-2'>
+                                        <Label>Require Certification</Label>
+                                        <Skeleton className='h-3 w-6' />
+                                    </div>
+                                )}
                                 {showAnalysisToggle && (
                                     <div className='grid gap-2'>
                                         <Label>Enable Analysis</Label>
                                         <Skeleton className='h-3 w-6' />
                                     </div>
                                 )}
+                                {isZonePage && (
+                                    <div className='grid gap-2'>
+                                        <Label>Apply Custom Glyph</Label>
+                                        <Skeleton className='h-20 w-full' />
+                                    </div>
+                                )}
                             </div>
                         </CardContent>
                     </Card>
@@ -300,6 +342,8 @@ export const TagForm: FC = () => {
 
     if (tagQuery.isError) return <div>There was an error fetching the tag information.</div>;
 
+    const glyph = getValues('glyph');
+
     return (
         <Form {...form}>
             <form className='flex gap-x-6 mt-6'>
@@ -358,6 +402,34 @@ export const TagForm: FC = () => {
                                         </FormItem>
                                     )}
                                 />
+                                {isZonePage && Certification && (
+                                    <FormField
+                                        control={control}
+                                        name='require_certify'
+                                        render={({ field }) => (
+                                            <FormItem>
+                                                <FormLabel>Require Certification</FormLabel>
+                                                <div className='flex gap-2'>
+                                                    <FormControl>
+                                                        <Switch
+                                                            {...field}
+                                                            value={field.value?.toString()}
+                                                            data-testid='privilege-zones_save_tag-form_require-certify-toggle'
+                                                            checked={field.value || false}
+                                                            onCheckedChange={field.onChange}></Switch>
+                                                    </FormControl>
+                                                    <p className='text-sm'>
+                                                        Enable this to mandate certification for all members within this
+                                                        zone
+                                                    </p>
+                                                </div>
+
+                                                <FormMessage />
+                                            </FormItem>
+                                        )}
+                                    />
+                                )}
+
                                 {showAnalysisToggle && (
                                     <FormField
                                         control={control}
@@ -379,6 +451,74 @@ export const TagForm: FC = () => {
                                         )}
                                     />
                                 )}
+                                {isZonePage && getValues('position') !== 1 && (
+                                    <FormField
+                                        control={control}
+                                        name='glyph'
+                                        render={({ field }) => (
+                                            <FormItem>
+                                                <FormLabel className='flex gap-2 items-center'>
+                                                    Apply Custom Glyph
+                                                    <Tooltip
+                                                        tooltip={
+                                                            'Custom glyphs visually mark nodes in the graph for quick context.'
+                                                        }
+                                                        contentProps={{
+                                                            className: 'max-w-80 dark:bg-neutral-dark-5 border-0',
+                                                            side: 'right',
+                                                            align: 'end',
+                                                        }}>
+                                                        <span>
+                                                            <AppIcon.Info />
+                                                        </span>
+                                                    </Tooltip>
+                                                </FormLabel>
+                                                <FormControl>
+                                                    <Input
+                                                        data-testid='privilege-zones_save_tag-form_glyph-input'
+                                                        type='text'
+                                                        className='hidden'
+                                                        {...field}
+                                                    />
+                                                </FormControl>
+                                                <div className='w-full flex items-end justify-between'>
+                                                    <div className='flex gap-4 text-sm'>
+                                                        <div>
+                                                            <p className='font-medium'>Selected Glyph:</p>
+                                                            <p className={clsx(glyph && 'italic')}>
+                                                                {glyph || 'None Selected'}
+                                                            </p>
+                                                        </div>
+
+                                                        <Card
+                                                            className={clsx([
+                                                                'flex items-center justify-center size-12',
+                                                                !glyph && 'invisible',
+                                                            ])}>
+                                                            <CardContent className='dark:bg-neutral-4 rounded-sm'>
+                                                                {glyph && (
+                                                                    <FontAwesomeIcon
+                                                                        icon={glyph as IconName}
+                                                                        size='lg'
+                                                                    />
+                                                                )}
+                                                            </CardContent>
+                                                        </Card>
+                                                    </div>
+                                                    <Button
+                                                        onClick={() => {
+                                                            setGlyphDialogOpen(true);
+                                                        }}
+                                                        className='w-48'
+                                                        variant={'secondary'}>
+                                                        <span>Select Glyph</span>
+                                                    </Button>
+                                                </div>
+                                                <FormMessage />
+                                            </FormItem>
+                                        )}
+                                    />
+                                )}
                                 <div className='hidden'>
                                     <FormField
                                         control={control}
@@ -444,11 +584,19 @@ export const TagForm: FC = () => {
                     />
                 )}
             </form>
+
+            <GlyphSelectDialog
+                open={glyphDialogOpen}
+                selected={glyph as IconName}
+                onCancel={handleGlyphCancel}
+                onSelect={handleGlyphSelect}
+            />
+
             <DeleteConfirmationDialog
                 isLoading={tagQuery.isLoading}
                 itemName={tagQuery.data?.name || tagType}
                 itemType={tagType}
-                onCancel={handleCancel}
+                onCancel={handleDeleteCancel}
                 onConfirm={handleDeleteTag}
                 open={deleteDialogOpen}
             />
