@@ -16,7 +16,10 @@
 
 import PrivilegeZones from './PrivilegeZones';
 
+export { EntitySelectorsInformation, SelectedDetails, getSavePath } from './Details/index';
+export * from './Filters';
 export * from './PrivilegeZonesContext';
 export * from './ZoneAnalysisIcon';
 export * from './utils';
+
 export default PrivilegeZones;
