@@ -17,8 +17,11 @@
 import { AxiosRequestConfig } from 'axios';
 import {
     AssetGroupTagSelector,
+    AssetGroupTagSelectorAutoCertifyType,
     AssetGroupTagSelectorSeed,
     AssetGroupTagType,
+    CertificationManual,
+    CertificationRevoked,
     SeedExpansionMethod,
     SSOProviderConfiguration,
 } from './types';
@@ -37,19 +40,30 @@ export type CreateAssetGroupTagRequest = {
     name: string;
     description: string;
     type: AssetGroupTagType;
+    glyph?: string;
     position?: number | null;
-    requireCertify?: boolean | null;
+    require_certify?: boolean | null;
 };
 
 export type UpdateAssetGroupTagRequest = Partial<
     Partial<CreateAssetGroupTagRequest> & { analysis_enabled?: boolean | undefined }
 >;
 
+export type UpdateCertificationRequest = {
+    member_ids: number[];
+    action: typeof CertificationRevoked | typeof CertificationManual;
+    note?: string;
+};
+
 export type PreviewSelectorsRequest = { seeds: SelectorSeedRequest[]; expansion: SeedExpansionMethod };
 
 export type SelectorSeedRequest = Pick<AssetGroupTagSelectorSeed, 'type' | 'value'>;
 
-export type CreateSelectorRequest = { name: string; description?: string } & { seeds: SelectorSeedRequest[] };
+export type CreateSelectorRequest = {
+    name: string;
+    description?: string;
+    auto_certify?: AssetGroupTagSelectorAutoCertifyType | null;
+} & { seeds: SelectorSeedRequest[] };
 
 export type UpdateSelectorRequest = Partial<CreateSelectorRequest & { disabled: boolean }> &
     Pick<AssetGroupTagSelector, 'id'>;
